@@ -13,14 +13,14 @@ test_that("CpR_sensitivity_plot returns the correct class of outputs", {
   # Create 20 random assemblages
   for(i in 1:20){
     # Create a random phylogeny
-    tree[[i]] <- ape::rcoal(20)
+    tree[[i]] <- ape::rcoal(20, br = c(min = 2, max = 10)) # Sets a minimum and maximum length for branch lengths
     # Create a random matrix
     mat[[i]] <- matrix(sample(c(1, 0), 20 * 10, replace = TRUE), ncol = 20, nrow = 10)
     colnames(mat[[i]]) <- tree[[i]]$tip.label # Name its columns according to tip names
   }
 
   # Creating a vector containing the number of slices desired to run the sensitivity
-  vec <- c(10, 25, 50, 75, 100)
+  vec <- c(25, 50, 75, 100, 125)
   # and the number of samples to evaluate it
   samp <- 10
 
